/* vim: set noet ts=4:
 *
 * Copyright (c) 2002-2006 Martin A. Godisch <martin@godisch.de>.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
 * St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef _CHARSET_H
#define _CHARSET_H

#include <stdlib.h>
#include <ncursesw/ncurses.h>

size_t utf2local(char*, size_t);
size_t iso2utf(char*, size_t);

inline void   make_digraph(wint_t, wint_t*);
inline size_t wcstrlen(const wchar_t*);
inline int    wcsappend(int, wchar_t*, wchar_t, size_t);
inline int    wcsbackspace(wchar_t*, wchar_t*);
inline void   wcsreverse(wchar_t*);
inline void   wcsaddn(wchar_t*, unsigned);

int load_keymap(int, const char*);

#endif
